pub struct ConnectNamespaceBuilder { /* private fields */ }Implementations
Sourceimpl ConnectNamespaceBuilder
impl ConnectNamespaceBuilder
Sourcepub fn storage_option(
self,
key: impl Into<String>,
value: impl Into<String>,
) -> Self
pub fn storage_option( self, key: impl Into<String>, value: impl Into<String>, ) -> Self
Set an option for the storage layer.
See available options at https://docs.lancedb.com/storage/
Sourcepub fn storage_options(
self,
pairs: impl IntoIterator<Item = (impl Into<String>, impl Into<String>)>,
) -> Self
pub fn storage_options( self, pairs: impl IntoIterator<Item = (impl Into<String>, impl Into<String>)>, ) -> Self
Set multiple options for the storage layer.
See available options at https://docs.lancedb.com/storage/
Sourcepub fn namespace_client_property(
self,
key: impl Into<String>,
value: impl Into<String>,
) -> Self
pub fn namespace_client_property( self, key: impl Into<String>, value: impl Into<String>, ) -> Self
Set an additional namespace client property.
Sourcepub fn namespace_client_properties(
self,
pairs: impl IntoIterator<Item = (impl Into<String>, impl Into<String>)>,
) -> Self
pub fn namespace_client_properties( self, pairs: impl IntoIterator<Item = (impl Into<String>, impl Into<String>)>, ) -> Self
Set multiple additional namespace client properties.
Sourcepub fn read_consistency_interval(
self,
read_consistency_interval: Duration,
) -> Self
pub fn read_consistency_interval( self, read_consistency_interval: Duration, ) -> Self
The interval at which to check for updates from other processes.
If left unset, consistency is not checked. For maximum read performance, this is the default. For strong consistency, set this to zero seconds. Then every read will check for updates from other processes. As a compromise, set this to a non-zero duration for eventual consistency.
Sourcepub fn embedding_registry(self, registry: Arc<dyn EmbeddingRegistry>) -> Self
pub fn embedding_registry(self, registry: Arc<dyn EmbeddingRegistry>) -> Self
Provide a custom EmbeddingRegistry to use for this connection.
Sourcepub fn session(self, session: Arc<Session>) -> Self
pub fn session(self, session: Arc<Session>) -> Self
Set a custom session for object stores and caching.
By default, a new session with default configuration will be created. This method allows you to provide a custom session with your own configuration for object store registries, caching, etc.
Sourcepub fn pushdown_operation(
self,
operation: NamespaceClientPushdownOperation,
) -> Self
pub fn pushdown_operation( self, operation: NamespaceClientPushdownOperation, ) -> Self
Add operations to push down to the namespace server.
When operations are added, they will be executed on the namespace server instead of locally. This can improve performance by reducing data transfer and leveraging server-side compute resources.
Available operations:
NamespaceClientPushdownOperation::QueryTable: Execute queries vianamespace.query_table()NamespaceClientPushdownOperation::CreateTable: Execute table creation vianamespace.create_table()
By default, no operations are pushed down (all executed locally).
Sourcepub fn pushdown_operations(
self,
operations: impl IntoIterator<Item = NamespaceClientPushdownOperation>,
) -> Self
pub fn pushdown_operations( self, operations: impl IntoIterator<Item = NamespaceClientPushdownOperation>, ) -> Self
Add multiple operations to push down to the namespace server.
See Self::pushdown_operation for details.
Sourcepub async fn execute(self) -> Result<Connection>
pub async fn execute(self) -> Result<Connection>
Execute the connection