ConnectRequest

Struct ConnectRequest 

pub struct ConnectRequest {
    pub uri: String,
    pub client_config: ClientConfig,
    pub options: HashMap<String, String>,
    pub namespace_client_properties: HashMap<String, String>,
    pub manifest_enabled: bool,
    pub read_consistency_interval: Option<Duration>,
    pub session: Option<Arc<Session>>,
}
A request to connect to a database

Fields

uri: String

Database URI

Accpeted URI formats
  • /path/to/database - local database on file system.
  • s3://bucket/path/to/database or gs://bucket/path/to/database - database on cloud object store
  • db://dbname - LanceDB Cloud
client_config: ClientConfigoptions: HashMap<String, String>

Database specific options

namespace_client_properties: HashMap<String, String>

Extra properties for the equivalent namespace client.

For a local ListingDatabase, these are merged into the backing DirectoryNamespace properties. This is useful for namespace-specific settings such as table_version_tracking_enabled that are distinct from storage options.

manifest_enabled: bool

Use directory namespace manifests as the source of truth for native LanceDB table metadata.

When enabled for a local/native connection, LanceDB returns a namespace-backed database directly. Directory listing fallback remains enabled for migration, and directory-listing-to-manifest migration is forced on.

read_consistency_interval: Option<Duration>

The interval at which to check for updates from other processes.

If None, then consistency is not checked. For performance reasons, this is the default. For strong consistency, set this to zero seconds. Then every read will check for updates from other processes. As a compromise, you can set this to a non-zero timedelta for eventual consistency. If more than that interval has passed since the last check, then the table will be checked for updates. Note: this consistency only applies to read operations. Write operations are always consistent.

session: Option<Arc<Session>>

Optional session for object stores and caching

If provided, this session will be used instead of creating a default one. This allows for custom configuration of object store registries, caching, etc.