pub struct NewTableConfig {
pub data_storage_version: Option<LanceFileVersion>,
pub enable_v2_manifest_paths: Option<bool>,
pub enable_stable_row_ids: Option<bool>,
}Expand description
Controls how new tables should be created
Fields
data_storage_version: Option<LanceFileVersion>The storage version to use for new tables
If unset, then the latest stable version will be used
enable_v2_manifest_paths: Option<bool>Whether to enable V2 manifest paths for new tables
V2 manifest paths are more efficient than V2 manifest paths but are not supported by old clients.
enable_stable_row_ids: Option<bool>Whether to enable stable row IDs for new tables
When enabled, row IDs remain stable after compaction, update, delete, and merges. This is useful for materialized views and other use cases that need to track source rows across these operations.