pub enum Error {
Show 20 variants
InvalidTableName {
name: String,
reason: String,
},
InvalidInput {
message: String,
},
TableNotFound {
name: String,
source: Box<dyn Error + Send + Sync>,
},
DatabaseNotFound {
name: String,
},
DatabaseAlreadyExists {
name: String,
},
IndexNotFound {
name: String,
},
EmbeddingFunctionNotFound {
name: String,
reason: String,
},
TableAlreadyExists {
name: String,
},
CreateDir {
path: String,
source: Error,
},
Schema {
message: String,
},
Runtime {
message: String,
},
Timeout {
message: String,
},
ObjectStore {
source: Error,
},
Lance {
source: Error,
},
Http {
source: Box<dyn Error + Send + Sync>,
request_id: String,
status_code: Option<StatusCode>,
},
Retry {
request_id: String,
request_failures: u8,
max_request_failures: u8,
connect_failures: u8,
max_connect_failures: u8,
read_failures: u8,
max_read_failures: u8,
source: Box<dyn Error + Send + Sync>,
status_code: Option<StatusCode>,
},
Arrow {
source: ArrowError,
},
NotSupported {
message: String,
},
External {
source: Box<dyn Error + Send + Sync>,
},
Other {
message: String,
source: Option<Box<dyn Error + Send + Sync>>,
},
}Variants
InvalidTableName
InvalidInput
TableNotFound
DatabaseNotFound
DatabaseAlreadyExists
IndexNotFound
EmbeddingFunctionNotFound
TableAlreadyExists
CreateDir
Schema
Runtime
Timeout
ObjectStore
Lance
Http
Fields

status_code: Option<StatusCode>Status code associated with the error, if available. This is not always available, for example when the error is due to a connection failure. It may also be missing if the request was successful but there was an error decoding the response.
Retry
Fields

status_code: Option<StatusCode>Arrow
Fields

source: ArrowErrorNotSupported
External
External error pass through from user code.
Other