pub struct MatchQuery {
pub column: Option<String>,
pub terms: String,
pub boost: f32,
pub fuzziness: Option<u32>,
pub max_expansions: usize,
pub operator: Operator,
pub prefix_length: u32,
}Fields
column: Option<String>terms: Stringboost: f32fuzziness: Option<u32>max_expansions: usizeThe maximum number of terms to expand for fuzzy matching. Default to 50.
operator: OperatorThe operator to use for combining terms.
This can be either And or Or, it’s ‘Or’ by default.
And: All terms must match.Or: At least one term must match.
prefix_length: u32The number of beginning characters being unchanged for fuzzy matching. Default to 0.
Implementations
Sourceimpl MatchQuery
impl MatchQuery
pub fn new(terms: String) -> MatchQuery
pub fn with_column(self, column: Option<String>) -> MatchQuery
pub fn with_boost(self, boost: f32) -> MatchQuery
pub fn with_fuzziness(self, fuzziness: Option<u32>) -> MatchQuery
pub fn with_max_expansions(self, max_expansions: usize) -> MatchQuery
pub fn with_operator(self, operator: Operator) -> MatchQuery
pub fn with_prefix_length(self, prefix_length: u32) -> MatchQuery
pub fn auto_fuzziness(token: &str) -> u32