Module query

Module query 

Structs

ColumnOrdering
Re-export Lance ColumnOrdering type for use in query ordering Defines an ordering for a single column
Query
A builder for LanceDB queries.
QueryExecutionOptions
Options for controlling the execution of a query
QueryRequest
A basic query into a table without any kind of search
TakeQuery
A builder for LanceDB take queries.
VectorQuery
A builder for vector searches
VectorQueryRequest
A request for a nearest-neighbors search into a table

Enums

QueryFilter
A query filter that can be applied to a query
Select
Which columns should be retrieved from the database

Traits

ExecutableQuery
A trait for a query object that can be executed to get results
HasQuery
IntoQueryVector
A trait for converting a type to a query vector
QueryBase
Common parameters that can be applied to scans and vector queries