pub struct Query { /* private fields */ }Expand description
A builder for LanceDB queries.
See crate::Table::query for more details on queries
See QueryBase for methods that can be used to parameterize
the query.
See ExecutableQuery for methods that can be used to execute
the query and retrieve results.
This query object can be reused to issue the same query multiple times.
Implementations
Sourceimpl Query
impl Query
Sourcepub fn nearest_to(self, vector: impl IntoQueryVector) -> Result<VectorQuery>
pub fn nearest_to(self, vector: impl IntoQueryVector) -> Result<VectorQuery>
Find the nearest vectors to the given query vector.
This converts the query from a plain query to a vector query.
This method will attempt to convert the input to the query vector expected by the embedding model. If the input cannot be converted then an error will be returned.
By default, there is no embedding model, and the input should be vector/slice of floats.
If there is only one vector column (a column whose data type is a
fixed size list of floats) then the column does not need to be specified.
If there is more than one vector column you must use [Query::column]
to specify which column you would like to compare with.
If no index has been created on the vector column then a vector query will perform a distance comparison between the query vector and every vector in the database and then sort the results. This is sometimes called a “flat search”
For small databases, with a few hundred thousand vectors or less, this can be reasonably fast. In larger databases you should create a vector index on the column. If there is a vector index then an “approximate” nearest neighbor search (frequently called an ANN search) will be performed. This search is much faster, but the results will be approximate.
The query can be further parameterized using the returned builder. There are various search parameters that will let you fine tune your recall accuracy vs search latency.
Arguments
vector- The vector that will be used for search.
pub fn into_request(self) -> QueryRequest
pub fn current_request(&self) -> &QueryRequest