pub struct Session { /* private fields */ }Expand description
Re-export Lance Session and ObjectStoreRegistry for custom session creation
A user session holds the runtime state for a crate::Dataset
A session will be created automatically when a Dataset is opened. However, you can manually create the session and provide it to the Dataset builder in order to share runtime state between multiple datasets.
This can be used to share caches between multiple datasets, increasing the hit rate and reducing the amount of memory used.
A session contains two different caches:
- The index cache is used to cache opened indices and will cache index data
- The metadata cache is used to cache a variety of dataset metadata (more details can be found in the performance guide
Implementations
Sourceimpl Session
impl Session
Sourcepub fn new(
index_cache_size: usize,
metadata_cache_size: usize,
store_registry: Arc<ObjectStoreRegistry>,
) -> Session
pub fn new( index_cache_size: usize, metadata_cache_size: usize, store_registry: Arc<ObjectStoreRegistry>, ) -> Session
Create a new session.
Parameters:
- index_cache_size: the size of the index cache.
- metadata_cache_size: the size of the metadata cache.
- store_registry: the object store registry to use when opening datasets. This determines which schemes are available, and also allows re-using object stores.
Sourcepub fn register_index_extension(
&mut self,
name: String,
extension: Arc<dyn IndexExtension>,
) -> Result<(), Error>
pub fn register_index_extension( &mut self, name: String, extension: Arc<dyn IndexExtension>, ) -> Result<(), Error>
Register a new index extension.
A name can only be registered once per type of index extension.
Parameters:
- name: the name of the extension.
- extension: the extension to register.
Sourcepub fn size_bytes(&self) -> u64
pub fn size_bytes(&self) -> u64
Return the current size of the session in bytes
Keep in mind that this is not trivial to compute, as we will need to walk the caches
Sourcepub fn approx_num_items(&self) -> usize
pub fn approx_num_items(&self) -> usize
Get the approximate number of items in the session.
This is a rough estimate of the number of items in the session. It is not exact and is not guaranteed to be accurate.
Sourcepub fn store_registry(&self) -> Arc<ObjectStoreRegistry>
pub fn store_registry(&self) -> Arc<ObjectStoreRegistry>
Get the object store registry.
Sourcepub async fn metadata_cache_stats(&self) -> CacheStats
pub async fn metadata_cache_stats(&self) -> CacheStats
Fetch statistics for the metadata cache
Sourcepub async fn index_cache_stats(&self) -> CacheStats
pub async fn index_cache_stats(&self) -> CacheStats
Fetch statistics for the index cache