LanceDB Table APIs
Re-exports
pub use query::AnyQuery;pub use delete::DeleteResult;pub use optimize::OptimizeAction;pub use optimize::OptimizeStats;pub use schema_evolution::AddColumnsResult;pub use schema_evolution::AlterColumnsResult;pub use schema_evolution::DropColumnsResult;pub use update::UpdateBuilder;pub use update::UpdateResult;pub use self::merge::MergeResult;
Modules
- datafusion
- This module contains adapters to allow LanceDB tables to be used as DataFusion table providers.
- delete
- merge
- optimize
- Table optimization operations for compaction, pruning, and index optimization.
- query
- schema_
evolution - Schema evolution operations for LanceDB tables.
- update
- write_
progress - Progress monitoring for write operations.
Structs
- AddData
Builder - A builder for configuring a
crate::table::Table::addoperation - AddResult
- Column
Alteration - Definition of a change to a column in a dataset
- Column
Definition - Defines a column in a table
- Compaction
Options - Options to be passed to compact_files.
- Dataset
Record Batch Stream DatasetRecordBatchStreamwraps the dataset into aRecordBatchStreamfor consumption by the user.- Fragment
Statistics - Fragment
Summary Stats - Lance
Tags - Tags operation
- Native
Table - A table in a LanceDB database.
- Native
Tags - Optimize
Options - Options for optimizing all indices.
- Read
Params - Customize read behavior of a dataset.
- Table
- A Table is a collection of strong typed Rows.
- Table
Definition - Table
Statistics - TagContents
- Version
- Dataset Version
- Write
Options - Options to use when writing data
Enums
- AddData
Mode - Column
Kind - Defines the type of column
- Filter
- Filters that can be used to limit the rows returned by a query
- NaNVector
Behavior - NewColumn
Transform - A way to define one or more new columns in a dataset
Traits
- Base
Table - A trait for anything “table-like”. This is used for both native tables (which target Lance datasets) and remote tables (which target LanceDB cloud)
- Native
Table Ext - Tags