pub struct WriteProgress { /* private fields */ }Expand description
Progress snapshot for a write operation.
Implementations
Sourceimpl WriteProgress
impl WriteProgress
Sourcepub fn output_rows(&self) -> usize
pub fn output_rows(&self) -> usize
Number of rows written so far.
Sourcepub fn output_bytes(&self) -> usize
pub fn output_bytes(&self) -> usize
Number of bytes written so far.
Sourcepub fn total_rows(&self) -> Option<usize>
pub fn total_rows(&self) -> Option<usize>
Total rows expected.
Populated when the input source reports a row count (e.g. a
arrow_array::RecordBatch). Always Some when WriteProgress::done
is true — falling back to the actual number of rows written.
Sourcepub fn active_tasks(&self) -> usize
pub fn active_tasks(&self) -> usize
Number of parallel write tasks currently in flight.
Sourcepub fn total_tasks(&self) -> usize
pub fn total_tasks(&self) -> usize
Total number of parallel write tasks (i.e. the write parallelism).