pub struct QueryRequest {
pub limit: Option<usize>,
pub offset: Option<usize>,
pub filter: Option<QueryFilter>,
pub full_text_search: Option<FullTextSearchQuery>,
pub select: Select,
pub fast_search: bool,
pub with_row_id: bool,
pub prefilter: bool,
pub reranker: Option<Arc<dyn Reranker>>,
pub norm: Option<NormalizeMethod>,
pub disable_scoring_autoprojection: bool,
pub order_by: Option<Vec<ColumnOrdering>>,
}Expand description
A basic query into a table without any kind of search
This will result in a (potentially filtered) scan if executed
Fields
limit: Option<usize>limit the number of rows to return.
offset: Option<usize>Offset of the query.
filter: Option<QueryFilter>Apply filter to the returned rows.
full_text_search: Option<FullTextSearchQuery>Perform a full text search on the table.
select: SelectSelect column projection.
fast_search: boolIf set to true, the query is executed only on the indexed data, and yields faster results.
By default, this is false.
with_row_id: boolIf set to true, the query will return the _rowid meta column.
By default, this is false.
prefilter: boolIf set to false, the filter will be applied after the vector search.
reranker: Option<Arc<dyn Reranker>>Implementation of reranker that can be used to reorder or combine query results, especially if using hybrid search
norm: Option<NormalizeMethod>Configure how query results are normalized when doing hybrid search
disable_scoring_autoprojection: boolIf set to true, disables automatic projection of scoring columns (_score, _distance). When disabled, these columns are only included if explicitly requested in the projection.
By default, this is false (scoring columns are auto-projected for backward compatibility).
order_by: Option<Vec<ColumnOrdering>>Sort the results by the specified column(s).
This allows ordering query results by one or more columns in either ascending or descending order.